11. Plotting in XmGrace — Jscatter 1.2.4 documentation

# 11. Plotting in XmGrace

## 11.1. GracePlot

`GracePlot` |
`jscatter.grace` |

`GracePlot.plot` |
`GracePlot.multi` |
`GracePlot.new_graph` |
`GracePlot.stacked` |
`GracePlot.clear` |
`GracePlot.exit` |
`GracePlot.legend` |
`GracePlot.save` |
`GracePlot.subtitle` |
`GracePlot.text` |
`GracePlot.title` |
`GracePlot.updateall` |
`GracePlot.write` |
`GracePlot.xaxis` |
`GracePlot.xlabel` |
`GracePlot.xlimit` |
`GracePlot.yaxis` |
`GracePlot.ylabel` |
`GracePlot.ylimit` |
`GracePlot.aspect_scale` |
`GracePlot.assign_color` |
`GracePlot.close` |
`GracePlot.command_args` |
`GracePlot.focus` |
`GracePlot.grace_command` |
`GracePlot.hold` |
`GracePlot.is_open` |
`GracePlot.load_parameter_file` |
`GracePlot.redraw` |
`GracePlot.resetlast` |
`GracePlot.resize` |
`GracePlot.resolution` |
`GracePlot.send_commands` |

## 11.2. GraceGraph

`GraceGraph.autoscale` |
`GraceGraph.autotick` |
`GraceGraph.clear` |
`GraceGraph.frame` |
`GraceGraph.gen_axis` |
`GraceGraph.grace` |
`GraceGraph.hold` |
`GraceGraph.kill` |
`GraceGraph.legend` |
`GraceGraph.line` |
`GraceGraph.plot` |
`GraceGraph.redraw` |
`GraceGraph.resetlast` |
`GraceGraph.subtitle` |
`GraceGraph.text` |
`GraceGraph.title` |
`GraceGraph.update_data` |
`GraceGraph.xaxis` |
`GraceGraph.xlabel` |
`GraceGraph.xlimit` |
`GraceGraph.yaxis` |
`GraceGraph.ylabel` |
`GraceGraph.ylimit` |

## 11.3. Helper Classes

`Annotation` |
`Bar` |
`Data` |
`DataBar` |
`DataXYBoxWhisker` |
`DataXYDX` |
`DataXYDXDX` |
`DataXYDXDXDYDY` |
`DataXYDXDY` |
`DataXYDY` |
`DataXYDYDY` |
`DataXYZ` |
`Errorbar` |
`Label` |
`Line` |
`Symbol` |
`Tick` |
`TickLabel` |
`colors` |
`fills` |
`frames` |
`lines` |
`symbols` |
`Disconnected` |
`format_scientific` |
`inheritDocstringFrom` |
`on_off` |